@@ -15,7 +15,7 @@ test_that("Single-group mean-based SSM results are correct", {
   expect_equal(round(res$results$y_est, 3), -0.264)
   expect_equal(round(res$results$a_est, 3), 0.981)
   expect_equal(as.vector(round(res$results$d_est, 1)), 344.4)
-  expect_equal(round(res$results$fit, 3), 0.954)
+  expect_equal(round(res$results$fit_est, 3), 0.954)
   expect_equal(res$results$label, "All")
   expect_equal(round(res$results$e_lci, 3), 0.131)
   expect_equal(round(res$results$e_uci, 3), 0.702)
@@ -65,7 +65,7 @@ test_that("Multiple-group mean-based SSM results are correct", {
   expect_equal(round(res$results$y_est, 3), c(-0.310, -0.186))
   expect_equal(round(res$results$a_est, 3), c(0.554, 0.294))
   expect_equal(as.vector(round(res$results$d_est, 3)), c(325.963, 320.685))
-  expect_equal(round(res$results$fit, 3), c(0.889, 0.824))
+  expect_equal(round(res$results$fit_est, 3), c(0.889, 0.824))
   expect_equal(res$results$label, c("Female", "Male"))
   expect_equal(round(res$results$e_lci, 3), c(0.907, 0.843))
   expect_equal(round(res$results$e_uci, 3), c(0.982, 0.925))
@@ -119,7 +119,7 @@ test_that("Multiple-group mean-based SSM contrast is correct", {
   expect_equal(round(res$results$y_est, 3), 0.124)
   expect_equal(round(res$results$a_est, 3), 0.263)
   expect_equal(round(res$results$d_est, 3), 151.858)
-  expect_equal(round(res$results$fit, 3), 0.855)
+  expect_equal(round(res$results$fit_est, 3), 0.855)
   expect_equal(res$results$label, "Male - Female")
   expect_equal(round(res$results$e_lci, 3), -0.116)
   expect_equal(round(res$results$e_uci, 3), -0.004)
@@ -193,7 +193,7 @@ test_that("Single-group correlation-based SSM results are correct", {
   expect_equal(round(res$results$y_est, 3), 0.117)
   expect_equal(round(res$results$a_est, 3), 0.150)
   expect_equal(as.vector(round(res$results$d_est, 1)), 128.9)
-  expect_equal(round(res$results$fit, 3), 0.802)
+  expect_equal(round(res$results$fit_est, 3), 0.802)
   expect_equal(res$scores$Group, factor("All"))
   expect_equal(res$scores$Measure, "PARPD")
   expect_equal(res$scores$label, "PARPD")
@@ -293,7 +293,7 @@ test_that("Measure-contrast correlation-based SSM results are correct", {
   expect_equal(round(res$results$y_est, 3), -0.024)
   expect_equal(round(res$results$a_est, 3), -0.037)
   expect_equal(round(res$results$d_est, 1), -7.0)
-  expect_equal(round(res$results$fit, 3), -0.007)
+  expect_equal(round(res$results$fit_est, 3), -0.007)
   expect_equal(res$results$label, "NARPD - ASPD")
   expect_equal(round(res$results$e_lci, 3), 0.039)
   expect_equal(round(res$results$e_uci, 3), 0.116)
@@ -349,7 +349,7 @@ test_that("Group-contrast correlation-based SSM results are correct", {
   expect_equal(round(res$results$y_est, 3), -0.056)
   expect_equal(round(res$results$a_est, 3), -0.068)
   expect_equal(round(res$results$d_est, 1), -10.4)
-  expect_equal(round(res$results$fit, 3), -0.071)
+  expect_equal(round(res$results$fit_est, 3), -0.071)
   expect_equal(res$results$label, "NARPD: Male - Female")
   expect_equal(round(res$results$e_lci, 3), 0.004)
   expect_equal(round(res$results$e_uci, 3), 0.140)
